import { AnalyticsMetadata } from '../analytics/interfaces';
import './styles.css.js';
export interface BaseComponentProps {
  /**
   * Adds the specified classes to the root element of the component.
   * @deprecated Custom CSS is not supported. For testing and other use cases, use [data attributes](https://developer.mozilla.org/en-US/docs/Learn/HTML/Howto/Use_data_attributes).
   */
  className?: string;
  /**
   * Adds the specified ID to the root element of the component.
   * @deprecated The usage of the `id` attribute is reserved for internal use cases. For testing and other use cases,
   * use [data attributes](https://developer.mozilla.org/en-US/docs/Learn/HTML/Howto/Use_data_attributes). If you must
   * use the `id` attribute, consider setting it on a parent element instead.
   */
  id?: string;
}
export declare function getBaseProps(props: BaseComponentProps): BaseComponentProps;
export declare function validateProps(componentName: string, props: Record<string, any>, excludedProps: Array<string>, allowedEnums: Record<string, Array<string>>): void;
export interface BasePropsWithAnalyticsMetadata {
  analyticsMetadata?: AnalyticsMetadata;
  __analyticsMetadata?: AnalyticsMetadata;
}
/**
 * Helper function to merge beta analytics metadata with the public analytics metadata api.
 * Beta analytics metadata will override the public values to allow for safe migration.
 */
export declare function getAnalyticsMetadataProps<T extends BasePropsWithAnalyticsMetadata>(props?: T): NonNullable<T['analyticsMetadata'] & T['__analyticsMetadata']>;